@@ -196,15 +196,24 @@ class common_v2(customwebDriverwait):
     '''
     def isElementDisplayed(self,locatorType:str,locator):
         try:
-            elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
-            if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.is_displayed()
-                else:
-                    self.__raise_element_not_visible_exception(locator)    
-            else:        
-                self.__raise_element_not_present_exception(locator)                    
+            if(locatorType.upper()=="XPATH"):
+                return self.driver.find_element((By.XPATH, locator)).is_displayed()
+            elif(locatorType.upper()=="ID"):
+                return self.driver.find_element((By.ID, locator)).is_displayed()                
+            elif(locatorType.upper()=="CLASS_NAME"):
+                return self.driver.find_element((By.CLASS_NAME, locator)).is_displayed()
+            elif(locatorType.upper()=="CSS_SELECTOR"):
+                return self.driver.find_element((By.CSS_SELECTOR, locator)).is_displayed()
+            elif(locatorType.upper()=="LINK_TEXT"):
+                return self.driver.find_element((By.LINK_TEXT, locator)).is_displayed()
+            elif(locatorType.upper()=="NAME"):
+                return self.driver.find_element((By.NAME, locator)).is_displayed()
+            elif(locatorType.upper()=="PARTIAL_LINK_TEXT"):
+                return self.driver.find_element((By.PARTIAL_LINK_TEXT, locator)).is_displayed()
+            elif(locatorType.upper()=="TAG_NAME"):
+                return self.driver.find_element((By.TAG_NAME, locator)).is_displayed()                
+            else:
+                raise Exception(" ** wrong selector/ no selector ** ",locatorType.upper())    
         except Exception as error:
             raise error             
     '''
@@ -212,17 +221,27 @@ class common_v2(customwebDriverwait):
     '''
     def isElementEnabled(self,locatorType:str,locator):
         try:
-            elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
-            if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.is_enabled() 
-                else:
-                    self.__raise_element_not_visible_exception(locator)
+            if(locatorType.upper()=="XPATH"):
+                return self.driver.find_element((By.XPATH, locator)).is_enabled()
+            elif(locatorType.upper()=="ID"):
+                return self.driver.find_element((By.ID, locator)).is_enabled()                
+            elif(locatorType.upper()=="CLASS_NAME"):
+                return self.driver.find_element((By.CLASS_NAME, locator)).is_enabled()
+            elif(locatorType.upper()=="CSS_SELECTOR"):
+                return self.driver.find_element((By.CSS_SELECTOR, locator)).is_enabled()
+            elif(locatorType.upper()=="LINK_TEXT"):
+                return self.driver.find_element((By.LINK_TEXT, locator)).is_enabled()
+            elif(locatorType.upper()=="NAME"):
+                return self.driver.find_element((By.NAME, locator)).is_enabled()
+            elif(locatorType.upper()=="PARTIAL_LINK_TEXT"):
+                return self.driver.find_element((By.PARTIAL_LINK_TEXT, locator)).is_enabled()
+            elif(locatorType.upper()=="TAG_NAME"):
+                return self.driver.find_element((By.TAG_NAME, locator)).is_enabled()                
             else:
-                self.__raise_element_not_present_exception(locator)             
+                raise Exception(" ** wrong selector/ no selector ** ",locatorType.upper())    
         except Exception as error:
-            raise error
+            raise error  
+
     '''
         Returns whether the element is selected.
 
@@ -230,15 +249,24 @@ class common_v2(customwebDriverwait):
     '''
     def isElementSelected(self,locatorType:str,locator):
         try:
-            elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
-            if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.is_selected() 
-                else:
-                    self.__raise_element_not_visible_exception(locator)
+            if(locatorType.upper()=="XPATH"):
+                return self.driver.find_element((By.XPATH, locator)).is_selected()
+            elif(locatorType.upper()=="ID"):
+                return self.driver.find_element((By.ID, locator)).is_selected()                
+            elif(locatorType.upper()=="CLASS_NAME"):
+                return self.driver.find_element((By.CLASS_NAME, locator)).is_selected()
+            elif(locatorType.upper()=="CSS_SELECTOR"):
+                return self.driver.find_element((By.CSS_SELECTOR, locator)).is_selected()
+            elif(locatorType.upper()=="LINK_TEXT"):
+                return self.driver.find_element((By.LINK_TEXT, locator)).is_selected()
+            elif(locatorType.upper()=="NAME"):
+                return self.driver.find_element((By.NAME, locator)).is_selected()
+            elif(locatorType.upper()=="PARTIAL_LINK_TEXT"):
+                return self.driver.find_element((By.PARTIAL_LINK_TEXT, locator)).is_selected()
+            elif(locatorType.upper()=="TAG_NAME"):
+                return self.driver.find_element((By.TAG_NAME, locator)).is_selected()                
             else:
-                self.__raise_element_not_present_exception(locator)                            
+                raise Exception(" ** wrong selector/ no selector ** ",locatorType.upper())    
         except Exception as error:
             raise error
     '''
